@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::Author::ETHER;
-# git description: v0.076-5-g9a831ad
-$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.077';
+# git description: v0.077-4-g44ad610
+$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.078';
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sw=4 tw=78 et :
@@ -349,7 +349,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.077
+version 0.078
 
 =head1 SYNOPSIS
 
@@ -654,6 +654,8 @@ many as you'd like), as described in L<Pod::Spell/ADDING STOPWORDS>:
 
 =for stopwords ModuleBuildTiny
 
+Available since 0.007.
+
 The installer back-end(s) to use (can be specified more than once); defaults
 to L<C<ModuleBuildTiny>|Dist::Zilla::Plugin::ModuleBuildTiny::Fallback>
 and L<C<MakeMaker::Fallback>|Dist::Zilla::Plugin::MakeMaker::Fallback>
@@ -673,6 +675,8 @@ Encouraged choices are:
 
 =head2 server
 
+Available since 0.019.
+
 If provided, must be one of:
 
 =over 4
@@ -716,6 +720,8 @@ you'll need to provide this yourself.
 
 =head2 airplane
 
+Available since 0.053.
+
 A boolean option, that when set, removes the use of all plugins that use the
 network (generally for comparing metadata against PAUSE, and querying the
 remote git server), as well as blocking the use of the C<release> command.
@@ -723,6 +729,8 @@ Defaults to false; can also be set with the environment variable C<DZIL_AIRPLANE
 
 =head2 copy_file_from_release
 
+Available in this form since 0.076.
+
 A file, to be present in the build, which is copied back to the source
 repository at release time and committed to git. Can be repeated more than
 once. Defaults to: F<LICENSE>, F<CONTRIBUTING>; defaults are appended to,
@@ -732,6 +740,8 @@ rather than overwritten.
 
 =for stopwords PodWeaver SurgicalPodWeaver
 
+Available since 0.051.
+
 A boolean option, that when set, uses
 L<[SurgicalPodWeaver]|Dist::Zilla::Plugin::SurgicalPodWeaver> instead of
 L<[PodWeaver]|Dist::Zilla::Plugin::SurgicalPodWeaver>, but with all the same
@@ -739,6 +749,8 @@ options. Defaults to false.
 
 =head2 changes_version_columns
 
+Available since 0.076.
+
 An integer that specifies how many columns (right-padded with whitespace) are
 allocated in Changes entries to the version string. Defaults to 10.
 
